==> progamification-0.0.19.tar.gz: lib/src/views/leaderboard/leader_board.dart <==
// ignore_for_file: library_private_types_in_public_api, no_logic_in_create_state, use_key_in_widget_constructors, prefer_const_constructors_in_immutables

import 'package:awesome_dialog/awesome_dialog.dart';
import 'package:progamification/src/components/leaderboard_info.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart';

class LeaderBoard extends StatefulWidget {
  final String userId;
  final String applicationId;
  LeaderBoard(this.userId, this.applicationId);
  @override
  _LeaderBoardState createState() => _LeaderBoardState(userId, applicationId);
}

class _LeaderBoardState extends State<LeaderBoard> {
  late String userId;
  late String applicationId;
  late bool isGamificationVisible;
  _LeaderBoardState(this.userId, this.applicationId);

  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();

  @override
  void initState() {
    super.initState();
    isGamificationVisible =
        leaderBoardController.getData(userId, applicationId);
    if (isGamificationVisible) {
      leaderBoardController.getRewards(userId, applicationId);
    }
  }

  @override
  Widget build(BuildContext context) {
    return isGamificationVisible
        ? Container(
            padding: const EdgeInsets.only(left: 0, right: 0),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
            ),
            child: Row(
              children: [
                InkWell(
                  onTap: (() {
                    leaderBoardController.getData(userId, applicationId);
                    leaderBoardController.getRewards(userId, applicationId);
                    AwesomeDialog(
                      context: context,
                      dialogType: DialogType.noHeader,
                      headerAnimationLoop: false,
                      animType: AnimType.topSlide,
                      showCloseIcon: false,
                      btnCancelOnPress: () {},
                      btnOkOnPress: () {},
                      btnOk: Container(),
                      btnCancel: Container(),
                      body: const LeaderboardInfo(),
                    ).show();
                  }),
                  child: Container(
                    margin: const EdgeInsets.all(2),
                    child: const Icon(
                      Icons.sports_score_outlined,
                      color: Colors.black,
                    ),
                  ),
                ),
              ],
            ),
          )
        : Container();
  }
}

==> progamification-0.0.23.tar.gz: lib/src/views/leaderboard/leader_board.dart <==
// ignore_for_file: library_private_types_in_public_api, no_logic_in_create_state, use_key_in_widget_constructors, prefer_const_constructors_in_immutables

import 'package:awesome_dialog/awesome_dialog.dart';
import 'package:progamification/src/components/leaderboard_info.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:flutter/material.dart';
import 'package:progamification/src/services/leaderboard.service.dart';

class LeaderBoard extends StatefulWidget {
  final String userId;
  final String applicationId;
  LeaderBoard(this.userId, this.applicationId);
  @override
  _LeaderBoardState createState() => _LeaderBoardState(userId, applicationId);
}

class _LeaderBoardState extends State<LeaderBoard> {
  late String userId;
  late String applicationId;
  bool isGamificationVisible = true;
  _LeaderBoardState(this.userId, this.applicationId);
  LeaderBoardService leaderBoardService = Get.find();

  final LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();

  @override
  void initState() {
    super.initState();
    getData(userId, applicationId);
  }

  Future<void> getData(String userId, String applicationId) async {
    try {
      await leaderBoardService
          .getLeaderBoard(userId, applicationId)
          .then(leaderBoardController.setData);
    } catch (e) {
      setState(() {
        isGamificationVisible = false;
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return isGamificationVisible
        ? Container(
            padding: const EdgeInsets.only(left: 0, right: 0),
            decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(10),
            ),
            child: Row(
              children: [
                InkWell(
                  onTap: (() async {
                    await leaderBoardController.getData(userId, applicationId);
                    await leaderBoardController.getRewards(
                        userId, applicationId);
                    AwesomeDialog(
                      context: context,
                      dialogType: DialogType.noHeader,
                      headerAnimationLoop: false,
                      animType: AnimType.topSlide,
                      showCloseIcon: false,
                      btnCancelOnPress: () {},
                      btnOkOnPress: () {},
                      btnOk: Container(),
                      btnCancel: Container(),
                      body: const LeaderboardInfo(),
                    ).show();
                  }),
                  child: Container(
                    margin: const EdgeInsets.all(2),
                    child: const Icon(
                      Icons.sports_score_outlined,
                      color: Colors.black,
                    ),
                  ),
                ),
              ],
            ),
          )
        : Container();
  }
}
